aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2002-04-22 15:17:27 +0000
committerjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2002-04-22 15:17:27 +0000
commit9ccad87ad118c36bec20447708348e7dd5c78fa1 (patch)
tree5194cff24d054d7ea11eb966206c71840d4d41c3
parentf37d988f03cacf03cec3c8da10a9394cb0c87af9 (diff)
rename direction cosines from (alpha,beta,gamma) --> (xcos,ycos,zcos)
git-svn-id: http://svn.einsteintoolkit.org/cactus/EinsteinAnalysis/AHFinderDirect/trunk@579 f88db872-0e4f-0410-b76b-b9085cfa78c5
-rw-r--r--src/gr/driver.cc14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/gr/driver.cc b/src/gr/driver.cc
index ae37612..0abc9f7 100644
--- a/src/gr/driver.cc
+++ b/src/gr/driver.cc
@@ -220,11 +220,11 @@ else CCTK_VWarn(-1, __LINE__, __FILE__, CCTK_THORNSTRING,
// ellipsoid has center (A,B,C), radius (a,b,c)
// angular coordinate system has center (U,V,W)
//
// direction cosines wrt angular coordinate center are (alpha,beta,gamma)
// i.e. a point has coordinates (U+alpha*r, V+beta*r, W+gamma*r)
//
// then the equation of the ellipsoid is
-// (U+alpha*r - A)^2 (V+beta*r - B)^2 (W+gamma*r - C)^2
+// (U+xcos*r - A)^2 (V+ycos*r - B)^2 (W+zcos*r - C)^2
// ----------------- + ---------------- + ----------------- = 1
// a^2 b^2 c^2
//
@@ -258,8 +258,8 @@ CCTK_VInfo(CCTK_THORNSTRING,
{
const fp rho = p.rho_of_irho(irho);
const fp sigma = p.sigma_of_isigma(isigma);
- fp alpha, beta, gamma;
- p.alpha_beta_gamma_of_rho_sigma(rho,sigma, alpha,beta,gamma);
+ fp xcos, ycos, zcos;
+ p.xyzcos_of_rho_sigma(rho,sigma, xcos,ycos,zcos);
// set up variables used by Maple-generated code
const fp AU = global_center_x - ps.origin_x();
@@ -283,12 +283,12 @@ CCTK_VInfo(CCTK_THORNSTRING,
"\n"
" expected exactly one r>0 solution, got 0 or 2!\n"
" %s patch (irho,isigma)=(%d,%d) ==> (rho,sigma)=(%g,%g)\n"
-" (alpha,beta,gamma)=(%g,%g,%g)\n"
+" direction cosines (xcos,ycos,zcos)=(%g,%g,%g)\n"
" ==> r_plus=%g r_minus=%g\n"
,
p.name(), irho, isigma,
double(rho), double(sigma),
- double(alpha), double(beta), double(gamma),
+ double(xcos), double(ycos), double(zcos),
double(r_plus), double(r_minus));
/*NOTREACHED*/
@@ -220,11 +220,11 @@ else CCTK_VWarn(-1, __LINE__, __FILE__, CCTK_THORNSTRING,
// angular coordinate system has center (U,V,W)
//
-// direction cosines wrt angular coordinate center are (alpha,beta,gamma)
-// i.e. a point has coordinates (U+alpha*r, V+beta*r, W+gamma*r)
+// direction cosines wrt angular coordinate center are (xcos,ycos,zcos)
+// i.e. a point has coordinates (U+xcos*r, V+ycos*r, W+zcos*r)
//
// then the equation of the ellipsoid is